#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Script for text to put in a djvu file 
Created at: 2008-12-09
Create a box file for a tiff image. 
This version of the tool is experimental.
Author: Mihail-Radu Solcan
Visit http://www.ub-filosofie.ro/~solcan/wt/wtc/index.html
"""
__copyright__ = "GPL"
__revision__ = "1"
__date__ = "2008-12-19"

import os
import sys

#SIDE_REF = 30

def findImageHeight(fileName):
    """Returns the height of the tiff image"""
    try:
        f = os.popen('identify -format "%h" ' + fileName)
        height = int(f.readline())
        f.close()
    except:
        exit(1)
    return height
#enddef

def findImageWidth(fileName):
    """Returns the width of the tiff image"""
    try:
        f = os.popen('identify -format "%w" ' + fileName)
        width = int(f.readline())
        f.close()
    except:
        exit(1)
    return width
#enddef

def negotiateRowSpan(imgHeight, side):
    """Determine the minimal height of a row"""
    if imgHeight >= side * 3:
        rowSpan = side
    else:
        rowSpan = int(imgHeight / 2)
    rest = imgHeight % rowSpan
    numberOfRows = imgHeight / rowSpan
    while rest >= numberOfRows:
        rowSpan += 1                # increase rowSpan
        rest = imgHeight % rowSpan
    return rowSpan

def negotiateColSpan(imgWidth, side):
    """Determine the minimal width of a column"""
    if imgWidth >= side * 3:
        colSpan = side
    else:
        colSpan = int(imgWidth / 2)
    rest = imgWidth % colSpan
    numberOfCols = imgWidth / colSpan
    while rest >= numberOfCols:
        colSpan += 1                # increase colSpan
        rest = imgWidth % colSpan
    return colSpan

def getBoxCoords(imgHeight, imgWidth):
    """List the coordinates of the boxes"""
    boxList = []
    refSide = len(str(tifHeight)) * 10
    if tifHeight >= 2:
        rowHeight = negotiateRowSpan(tifHeight, refSide)
        hrest = imgHeight % rowHeight
    else:
        rowHeight = tifHeight
        print "No rows"
    refSide = len(str(tifWidth)) * 10
    if tifWidth >= 2:
        colWidth = negotiateColSpan(tifWidth, refSide)
        crest = imgWidth % colWidth
    else:
        colWidth = tifWidth
        print "No columns"
    height = imgHeight
    width = 0
    while height > 0:
        if hrest > 0:
            dimHeight = rowHeight + 1       # distribute the rest
            hrest -= 1
        else:
            dimHeight = rowHeight
        xleft = width
        ydown = height - dimHeight
        yup = height
        while width < imgWidth:
            rest = crest
            if rest > 0:
                dimWidth = colWidth + 1     # spread rest among columns
                rest -= 1
            else:
                dimWidth = colWidth
            xright = width + dimWidth
            boxList += \
                ['. ' + `xleft` + ' ' + `ydown` + ' '\
                        + `xright` + ' ' + `yup` + '\n']
            width += dimWidth
            xleft = width
        width = 0
        height -= dimHeight
    return boxList

# Call the script from the commandline
# Process two input files and output one file
if __name__ == "__main__":
    boxText = []
    if len(sys.argv)>=2 and sys.argv[1] != "":
        tifFilename = sys.argv[1]
        tifHeight = findImageHeight(tifFilename)
        tifWidth = findImageWidth(tifFilename)
        boxText = getBoxCoords(tifHeight, tifWidth)
    else:
        tifFilename = "None"
        print "No image file"

    # Prepare a file for writing the text to put behind djvu
    boxFilename = tifFilename.replace('.tif', '.grid')
    fout = open(boxFilename,'w')

    for a_line in boxText:
        fout.write(a_line)

    # close the file with the data for the grid
    fout.close()
# This finishes the process.

